# aviary.gsm8k

GSM8k environment implemented with aviary,
allowing agents to solve math word problems from the GSM8k dataset.

## Citation

The citation for GSM8k is given below:

```bibtex
@article{gsm8k-paper,
    title = {Training verifiers to solve math word problems},
    author = {Cobbe, Karl and Kosaraju, Vineet and Bavarian, Mohammad and Chen, Mark and Jun, Heewoo and Kaiser, Lukasz and
 Plappert, Matthias and Tworek, Jerry and Hilton, Jacob and Nakano, Reiichiro and others},
    journal = {arXiv preprint arXiv:2110.14168},
    year = {2021}
}
```

## References

[1] Cobbe, K., Kosaraju, V., Bavarian, M., Chen, M., Jun, H., Kaiser, L., Plappert, M., Tworek, J., Hilton, J., Nakano,
R. and Hesse, C., 2021.
[Training verifiers to solve math word problems](https://arxiv.org/abs/2110.14168). arXiv preprint arXiv:2110.14168.

## Installation

To install the GSM8k environment, run the following command:

```bash
pip install fhaviary[gsm8k]
```
